abstemious
agitprop
allochthon
anagnorisis
bibliophil
brumous
cacomixl
caliginos
carrefour
catenate
chrysalid
coadjutor
cymograph
decumbent
defervesc
denoument
dextrous
diastole
echolalia
eclosion
ectotherm
epinician
epistasis
exiguous
filicoid
fissipede
frondesc
glabrous
granulite
guerdoned
hapticall
heliolatr
heteronym
hyalophan
ichthyoid
ignescent
incondite
infrasonic
jumentous
labdanum
lecanorin
lilaceous
lithiasis
lycanthrop
maledicti
masticate
mesolithic
molybdous
monostich
nidifugous
noctiluca
nonplussed
ommatidia
orphicall
outswirls
paeanism
paltrily
pandurate
parhelion
penstemon
perianth
phalanger
phylloid
planation
plasmodes
polemical
polymath
preludial
proboscis
quaaludes
rachitism
rachitome
raffishly
replevin
rhizoidal
saccharin
scandent
schizopod
sclerotic
selenitic
sesquiped
sinistral
somnolent
spermatog
spoliator
staphylin
stramash
subserene
subsonic
sulfurous
tautonym
telangiect
tenebrism
tetrapod
theomachy
threnodic
tomentous
triclinic
trifolium
trilithon
trochaic
tuffaceous
uredinial
uropygial
verjuice
vermicide
volplane
voracious
vorlage
vulpicide
waspishly
whigmalee
xerophyte
xylography
yarwhip
zibeline
zygodacty
adventure
agricultural
airplane
alphabetical
apartment
attention
beautiful
bathroom
bedroom
bicycle
birthday
breakfast
businessman
camera
careful
celebration
cemetery
character
computer
condition
consciousness
control
conversation
cousin
dangerous
delicious
democracy
department
difference
difficult
disappointed
doctor
electricity
employee
environment
equipment
everything
examination
excitement
experience
extraordinary
famous
father
February
feeling
finance
fireplace
football
foreigner
friendship
furniture
generation
girlfriend
government
grandfather
grandmother
happiness
historical
hospital
hotel
important
independence
interesting
interview
invitation
language
library
lightbulb
mathematics
medicine
millionaire
minimum
mischievous
motorcycle
necessary
newspaper
notebook
October
office
opportunity
organization
painting
pencil
permission
pharmacy
photograph
physical
picture
playground
population
position
positive
possible
powerful
prescription
presentation
problem
program
pronunciation
protection
psychology
publication
quantity
refrigerator
relationship
research
restaurant
revolution
scientist
secretary
security
sensitive
sentence
situation
software
special
statement
student
success
surprised
teacher
television
temperature
terrible
tomorrow
tourist
transportation
university
vegetable
victory
vocabulary
volunteer
weather
weekend
wonderful
worker
ambulance
automobile
average
beginning
boyfriend
bravery
breathe
business
calculate
calendar
calmness
campaign
candidate
capital
captain
career
cautious
celebrate
celebrity
century
chairman
challenge
champion
chemistry
chicken
childhood
colleague
collection
comfortable
comment
committee
common
compare
compassion
compete
complexity
confidence
confirm
conflict
congratulate
congress
connection
conscious
consequence
consider
consist
constant
continue
contrast
contribute
controversial
convention
cooperation
coordinate
courage
create
creative
credit
culture
curious
customer
daughter
decide
decision
decorate
dedicated
defeat
defend
definition
degree
deliver
describe
dessert
determine
develop
development
device
diagnose
dictionary
disappear
disappoint
discussion
disease
dismiss
distance
distinct
distract
distribute
disturb
diversity
divide
document
domestic
dominate
dramatic
employer
energy
enforce
engage
enhance
entertain
entrepreneur
epidemic
equal
equivalent
evaluate
event
evidence
evident
evolution
example
excellent
exchange
exercise
exhibition
exist
expect
expensive
experiment
expert
explain
exploration
express
extend
extension
extreme
facility
faith
familiar
fantasy
fascinating
fashion
favorite
feature
federal
feedback
festival
fierce
figure
film
financial
flavor
flexible
forecast
foreign
formality
formation
formula
fortunate
foundation
fraction
freedom
frustration
future
generous
genius
genuine
geography
gesture
global
graduate
gracious
gratitude
guarantee
guideline
guilty
habit
handsome
hardship
healthy
heaven
highlight
history
holiday
hospitality
humanity
humorous
identity
illegal
illustrate
imagination
immigrant
impact
importance
impossible
impress
impressio
increase
independent
index
individual
industrial
infant
inflate
influence
inform
ingredient
inherit
initial
innovation
input
inquire
instinct
insurance
intellect
intelligent
intensity
intention
interest
interfere
introduce
invention
investigate
island
journey
justice
laboratory
lack
laundry
address
analyze
announce
appeal
arrival
assist
balance
battery
benefit
blanket
border
borrower
ceiling
checkout
citizen
claim
clarify
classic
climate
combine
comfort
complex
concern
conduct
contact
contest
context
cooking
crucial
damage
danger
declare
default
define
delete
demand
desert
design
desire
destroy
detail
dictate
diet
differ
dimension
dinner
direct
disability
discipline
discard
disgust
district
divorce
donate
duration
eastern
economy
educate
effect
effort
either
element
empower
enable
encourage
engineer
enroll
ensure
enterprise
episode
error
escape
evening
exclude
excuse
execute
exhibit
expense
explore
fabric
factory
failure
fellow
female
finish
fitness
flight
follow
foolish
format
fortune
foster
framework
garage
gender
genre
grant
grateful
grave
honest
honor
horror
humble
humidity
ignore
imagine
import
income
include
flimflam
hocus-pocus
gobbledygook
higgledy-piggledy
hooptydo
kerfuffle
mumpsimus
peccadillo
razzle-dazzle
spifflicated
blithering
boojum
fiddlesticks
flummox
gibble-gabble
hootenanny
hootenoodle
hokum
piffle
beleaguer
capricious
cosset
dubitation
erstwhile
fervidly
gainsay
gratuity
irksome
skedaddle
quandary
lollygag
lassitude
fandangle
whippersnapper
flibbertigibbet
tittle-tattle
twaddle
Languid
Maelstrom
Melancholy
Nadir
Obsequious
Onomatopoeia
Paean
Panacea
Penultimate
Perfunctory
Plethora
Propinquity
Quandary
Querulous
Recondite
Redolent
Refractory
Reprieve
Sinecure
Sporadic
Squander
Staid
Stymie
Sullen
Taciturn
Tedious
Tepid
Turgid
Ubiquitous
Unexceptionable
Unfathomable
Unsullied
Vexation
Vexatious
Visceral
Voluble
Wanton
Wilting
Wily
Wistful


ability
accept
across
action
actual
advice
affect
almost
among
amount
animal
answer
anyone
appear
around
arrive
article
artist
aspect
assume
attack
attend
author
avoid
become
before
begin
behind
believe
better
beyond
bother
breath
brief
budget
center
chance
change
choice
circle
class
clear
close
coffee
contain
costume
country
couple
course
double
dreamer
driver
during
easily
entire
equally
especially
exactly
except
factor
family
feather
finally
finger
forget
former
forward
friend
garden
general
glass
grandma
greater
ground
growth
happen
health
hearty
height
himself
improve
instead
involve
itself
jacket
judge
kitchen
knowledge
leader
lesson
letter
likely
little
living
locate
lonely
manage
manner
market
master
matter
medium
member
memory
mention
middle
minute
modern
moment
mother
myself
nation
nature
nearby
normal
notice
number
object
occur
offer
often
online
oppose
option
organ
origin
parent
partner
person
phrase
planet
please
plenty
pocket
police
popular
portion
potato
powder
power
prefer
prepare
present
pretty
prevent
primary
prince
private
process
produce
profit
promote
proper
protect
provide
public
puzzle
quality
quickly
quietly
rather
recent
reduce
reflect
region
relate
remain
remind
remove
repair
repeat
report
require
reserve
respect
result
return
reveal
review
reward
routine
school
screen
season
second
secret
sector
secure
select
senior
series
serious
serve
settle
severe
should
shower
simple
simply
sister
source
speech
spirit
spread
spring
square
stable
status
street
strong
sudden
suffer
summer
supply
support
surely
survey
switch
system
taught
temple
tennis
thanks
theory
there
these
thick
thing
thinker
third
thirty
though
threat
three
tissue
toward
travel
treaty
tricks
triple
trouble
trustee
twelve
twenty
unable
unique
unless
until
update
usual
vacuum
valley
various
victim
vision
visual
volume
wealth
weight
welcome
whole
window
winter
wonder
worry
worse
worth


Fervently
Futurist
Gargoyle
Gesticulate
Glibness
Gossamer
Gravitas
Grimace
Gustatory
Habitual
Halcyon
Harbinger
Hegemony
Hemisphere
Heterodox
Hiatus
Hindrance
Humdrum
Hypothesis
Iconoclast
Ignominy
Illusive
Immutable
Impasse
Impetuous
Implacable
Inadvertent
Incarcerate
Incessant
Inchoate
Incipient
Indefatigable
Indelible
Indigent
Indomitable
Inertia
Infamous
Infinitesimal
Inimical
Innocuous
Insidious
Insolvent
Intangible
Interminable
Inundate
Inveterate
Irascible
Jocular
Judicious
Kaleidoscope
Laconic
Lamentable
Laudable
Lethargic
Levity
Loquacious
Magnanimous
Maladroit
Malleable
Maverick
Mellifluous
Mendacity
Meticulous
Misanthrope
Mitigate
Mollify
Morose
Mundane
Nascent
Nebulous
Nefarious
Nostalgia
Noxious
Nuance
Oblivious
Onerous
Opaque
Opprobrium
Ostentatious
Paradigm
Pariah
Parsimony
Penchant
Penury
Perfidy
Permeate
Perpetuate
Pervade
Pervasive
Petulant
Plummet
Precarious
Precipitate
Precursor
Prescience
Presumptuous
Prevaricate
Primordial
Probity
Proclivity
Prodigal
Profane
Proliferate
Propensity
Propitiate
Prosaic
Pungent
Quagmire
Quixotic
Raconteur
Rancor
Recalcitrant
Recant
Redoubtable
Refulgent
Relegate
Remiss
Repudiate
Resilient
Resonant
Reticent
Reverberate
Risible
Rudimentary
Rueful
Sagacious
Salubrious
Sanguine
Sardonic
Savant
Scrupulous
Sedulous
Solicitous
Soporific
Specious
Stoic
Strident
Subpoena
Subtlety
Superfluous
Supplant
Surfeit
Sycophant
Tenacious
Tirade
Tractable
Transient
Truculent
Unctuous
Usurp
Vacillate
Vapid
Venerable
Veracity
Vicissitude
Virulent
Voracious
Waft
Welter
Winsome
Wizened
Wrought
Xenophobia
Yoke
Zealot
Zephyr
apostasy
arcanum
asceticism
autodidact
balneology
calumny
candelabra
cantankerous
carpophagous
cassareep
cataclysm
cerement
chrysolite
clinamen
cognoscente
commensal
congeries
consignee
contravene
cormorant
credence
cunctation
daguerreot
deleterious
demagogue
dendrology
depurate
desuetude
diaphonics
dichogamy
disestablishment
disinherit
dissentient
dissimulate
dolorifuge
dormitive
drossiness
dulcet
ebullience
ecumenical
encomiast
enmity
epistolary
eponym
eristic
expectance
farrago
fecundate
florilegium
frustule
fuliginous
fulsomeness
fustigate
galvanism
gemmule
genuflect
glamour
globule
gossamer
gracile
grandiloquent
hale
halcyon
hebdomadal
hegira
hibernacle
horripilation
hydraulics
hymenopteran
hypostasis
ignis fatuus
immure
incunabulum
indefatigable
indigent
infelicitous
infinitesimal
inscrutable
intemperate
interregnum
irrefragable
irrupt
jocundity
juggernaut
kakistocracy
kilter
kleptomania
lachrymose
lampoon
latifundium
legerdemain
levee
lissome
lucubration
luminescent
lurid
machinate
malapropism
malediction
malefactor
malfeasance
malinger
malleable
maraud
marcescent
mellifluous
mendacity
mendicancy
meretricious
mesomorphic
mettle
miasma
mignonette
misoneism
mitigate
modicum
mollify
museology
nefarious
neologism
neoteny
nepotism
nihilism
obdurate
obsequious
obstinate
obstreperous
obviate
odious
olfaction
onomatopoeia
ossify
ostensible
palliate
pallor
panegyric
parsimony
patois
pecunious
pellucid
penultimate
perfidy
perfunctory
peripatetic
persiflage
petulant
phlegmatic
pittance
plenitude
plethora
plumage
plutocracy
polemics
postulate
prattle
precipitate
precocious
predilection
prelate
presage
probity
profligate
prolegomena
promulgate
propinquity
propound
prosaic
provident
pulchritude
punctilious
pusillanimous
quaff
quiescent
quotidian
raconteur
raillery
recond
pron


# __init__.py
from .__main__ import main
from .hashwd import generate_password
from .defaults import WORDS_DEFAULT, NUMBERS_DEFAULT, SYMBOLS_DEFAULT, DICTIONARY_FILE, SYMBOLS, MAX_SYMBOLS, MAX_NUMBERS



## Defaults for the respective values in hashwd.py

# Define constants for the allowed range of values for number of words, numbers, and symbols
MIN_WORDS = 1
MAX_WORDS = 99
MIN_NUMBERS = 0
MAX_NUMBERS = 9
MIN_SYMBOLS = 0
MAX_SYMBOLS = 10

# Define the list of symbols that can be included in the password
SYMBOLS = ["!", "@", "#", "_", "-", "?", "(", ")", "[", "]"]

# Define the dictionary file filepath
DICTIONARY_FILE = "C:/hashwd/dictionary.py"

# Define the default number of words, numbers, and symbols when generating a password without arguments or prompts
WORDS_DEFAULT = 4
NUMBERS_DEFAULT = 2
SYMBOLS_DEFAULT = 1


# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['hashwd', 'defaults', 'dictionary', '__main__', '__init__', 'LICENSE']
install_requires = \
['argparse>=1.4,<2.0', 'pyperclip>=1.8,<2.0', 'requests>=2.24,<3.0']

entry_points = \
{'console_scripts': ['hashwd = hashwd.__main__:main']}

setup_kwargs = {
    'name': 'hashwd',
    'version': '0.4.5',
    'description': 'Quickly generate a strong, random password using common words',
    'long_description': 'hashwd\n\nIntroduction\nhashwd is a command-line application that generates strong, random passwords using a list of words and optional numbers and symbols. The password is generated by randomly selecting words from a dictionary file, capitalizing one of the words, and adding optional numbers and symbols at the beginning or end of the password.\n\nCommands\ngenerate: generates a new password using the default or custom parameters\nclear: clears the OS clipboard\nArguments\n-h, --help: Show the help message and exit\n-d, --default: Use default values for number of words, numbers, and symbols\n-w, --words: Number of words in the password (must be between 1 and 99)\n-n, --numbers: Number of numbers in the password (must be between 0 and 9)\n-s, --symbols: Number of symbols in the password (must be between 0 and 9)\n-c, --copy: Copy the password to the clipboard\n-S, --show: Print the password to the console\n-P, --prompt: Prompt for number of words, numbers, and symbols\nUsage\nTo use the script, run the following command in the terminal:\n\nCopy code\npython hashwd.py generate [-h] [-d] [-w W] [-n N] [-s S] [-c] [-S] [-P] [-C]\nGenerate a password with the default number of words, numbers, and symbols:\nCopy code\npython hashwd.py generate\nGenerate a password with 5 words, 2 numbers, and 3 symbols:\nCopy code\npython hashwd.py generate -w 5 -n 2 -s 3\nGenerate a password and prompt for the number of words, numbers, and symbols. Additionally, print the password to the terminal and copy it to the clipboard automatically:\nCopy code\npython hashwd.py -PSc\nClear the clipboard:\nCopy code\npython hashwd.py clear\nRequirements\nPython 3\npyperclip (for copying the password to the clipboard)\nNote\nThe dictionary file is currently set to C:/hashwd/dictionary.txt. If you wish to use a different dictionary file, you can update the DICTIONARY_FILE constant in the script.\n\nLicense\nhashwd is released under the GNU General Public License v3.0.\n\nCredits\nhashwd was developed by Jordan Langland, 2023.',
    'author': 'Jordan Langland',
    'author_email': 'root@gnom.me',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/stellarsu/hashwd',
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
